# partcad

PartCAD is the first package manager for CAD files.
This Python module is the core part of PartCAD.

This module can be used in Python scripts to instantiate parts,
assemblies and scenes implemented as PartCAD packages.
Such instances can be used in [CadQuery] and [build123d] scripts.
They can also be used in custom web, mobile and desktop applications
that render CAD models.

For command line PartCAD tools, see the Python module `partcad-cli` instead.

See [the main PartCAD repo](https://github.com/openvmp/partcad/) for more information.

[CadQuery]: https://github.com/CadQuery/cadquery
[build123d]: https://github.com/gumyr/build123d